@@ -12,7 +12,6 @@
 """Kaleidoscope"""
 
 import os
-import kaleidoscope.configrc as config
 from kaleidoscope.errors import KaleidoscopeError
 
 # This is needed because version info is only generated
@@ -33,13 +32,3 @@ except ImportError:
     HAS_QISKIT = False
 else:
     HAS_QISKIT = True
-
-# Look for config file
-has_rc, rc_file = config.has_kal_rc()
-if not has_rc:
-    config.generate_kal_rc()
-    has_rc, rc_file = config.has_kal_rc()
-    # Write open provider as default when generating new file.
-    config.write_rc_key(rc_file, 'default_provider', 'ibm-q//open//main')
-if not has_rc:
-    raise KaleidoscopeError('Could not find or generate kalrc file.')
